.. :changelog:

History
=======

0.2.0 (2015-10-24)
------------------
Streamlining of the code and CLI. This causes some backward
incompatibility with `metadata.yaml` config files in version 0.1.0, in
particular, the "source" section is now required. There is now a defined schema
for the metadata and the grouping files so that future changes can be validated
and automatically fixed.


0.1.0 (2014-01-11)
---------------------

* First release on PyPI.
